==> openshift-model-machine-5.12.1-sources.jar: io/fabric8/openshift/api/model/machine/v1beta1/MachineStatusBuilder.java <==
package io.fabric8.openshift.api.model.machine.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class MachineStatusBuilder extends io.fabric8.openshift.api.model.machine.v1beta1.MachineStatusFluentImpl<io.fabric8.openshift.api.model.machine.v1beta1.MachineStatusBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.machine.v1beta1.MachineStatus,io.fabric8.openshift.api.model.machine.v1beta1.MachineStatusBuilder>{
  public MachineStatusBuilder() {
    this(false);
  }
  public MachineStatusBuilder(java.lang.Boolean validationEnabled) {
    this(new MachineStatus(), validationEnabled);
  }
  public MachineStatusBuilder(io.fabric8.openshift.api.model.machine.v1beta1.MachineStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public MachineStatusBuilder(io.fabric8.openshift.api.model.machine.v1beta1.MachineStatusFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new MachineStatus(), validationEnabled);
  }
  public MachineStatusBuilder(io.fabric8.openshift.api.model.machine.v1beta1.MachineStatusFluent<?> fluent,io.fabric8.openshift.api.model.machine.v1beta1.MachineStatus instance) {
    this(fluent, instance, false);
  }
  public MachineStatusBuilder(io.fabric8.openshift.api.model.machine.v1beta1.MachineStatusFluent<?> fluent,io.fabric8.openshift.api.model.machine.v1beta1.MachineStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAddresses(instance.getAddresses()); 
    fluent.withConditions(instance.getConditions()); 
    fluent.withErrorMessage(instance.getErrorMessage()); 
    fluent.withErrorReason(instance.getErrorReason()); 
    fluent.withLastOperation(instance.getLastOperation()); 
    fluent.withLastUpdated(instance.getLastUpdated()); 
    fluent.withNodeRef(instance.getNodeRef()); 
    fluent.withPhase(instance.getPhase()); 
    fluent.withProviderStatus(instance.getProviderStatus()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public MachineStatusBuilder(io.fabric8.openshift.api.model.machine.v1beta1.MachineStatus instance) {
    this(instance,false);
  }
  public MachineStatusBuilder(io.fabric8.openshift.api.model.machine.v1beta1.MachineStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withAddresses(instance.getAddresses()); 
    this.withConditions(instance.getConditions()); 
    this.withErrorMessage(instance.getErrorMessage()); 
    this.withErrorReason(instance.getErrorReason()); 
    this.withLastOperation(instance.getLastOperation()); 
    this.withLastUpdated(instance.getLastUpdated()); 
    this.withNodeRef(instance.getNodeRef()); 
    this.withPhase(instance.getPhase()); 
    this.withProviderStatus(instance.getProviderStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.machine.v1beta1.MachineStatusFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.machine.v1beta1.MachineStatus build() {
    MachineStatus buildable = new MachineStatus(fluent.getAddresses(),fluent.getConditions(),fluent.getErrorMessage(),fluent.getErrorReason(),fluent.getLastOperation(),fluent.getLastUpdated(),fluent.getNodeRef(),fluent.getPhase(),fluent.getProviderStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    MachineStatusBuilder that = (MachineStatusBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-machine-6.5.1-sources.jar: io/fabric8/openshift/api/model/machine/v1beta1/MachineStatusBuilder.java <==
package io.fabric8.openshift.api.model.machine.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class MachineStatusBuilder extends MachineStatusFluentImpl<MachineStatusBuilder> implements VisitableBuilder<MachineStatus,MachineStatusBuilder>{
  public MachineStatusBuilder() {
    this(false);
  }
  public MachineStatusBuilder(Boolean validationEnabled) {
    this(new MachineStatus(), validationEnabled);
  }
  public MachineStatusBuilder(MachineStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public MachineStatusBuilder(MachineStatusFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new MachineStatus(), validationEnabled);
  }
  public MachineStatusBuilder(MachineStatusFluent<?> fluent,MachineStatus instance) {
    this(fluent, instance, false);
  }
  public MachineStatusBuilder(MachineStatusFluent<?> fluent,MachineStatus instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAddresses(instance.getAddresses()); 
    fluent.withConditions(instance.getConditions()); 
    fluent.withErrorMessage(instance.getErrorMessage()); 
    fluent.withErrorReason(instance.getErrorReason()); 
    fluent.withLastOperation(instance.getLastOperation()); 
    fluent.withLastUpdated(instance.getLastUpdated()); 
    fluent.withNodeRef(instance.getNodeRef()); 
    fluent.withPhase(instance.getPhase()); 
    fluent.withProviderStatus(instance.getProviderStatus()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public MachineStatusBuilder(MachineStatus instance) {
    this(instance,false);
  }
  public MachineStatusBuilder(MachineStatus instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withAddresses(instance.getAddresses()); 
    this.withConditions(instance.getConditions()); 
    this.withErrorMessage(instance.getErrorMessage()); 
    this.withErrorReason(instance.getErrorReason()); 
    this.withLastOperation(instance.getLastOperation()); 
    this.withLastUpdated(instance.getLastUpdated()); 
    this.withNodeRef(instance.getNodeRef()); 
    this.withPhase(instance.getPhase()); 
    this.withProviderStatus(instance.getProviderStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  MachineStatusFluent<?> fluent;
  Boolean validationEnabled;
  public MachineStatus build() {
    MachineStatus buildable = new MachineStatus(fluent.getAddresses(),fluent.getConditions(),fluent.getErrorMessage(),fluent.getErrorReason(),fluent.getLastOperation(),fluent.getLastUpdated(),fluent.getNodeRef(),fluent.getPhase(),fluent.getProviderStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
